@@ -44,6 +44,7 @@ setClass("BSRInferenceComp",
     )
 )
 
+
 setValidity(
     "BSRInferenceComp",
     function(object) {
@@ -70,6 +71,7 @@ setValidity(
     }
 )
 
+
 setMethod(
     "show", "BSRInferenceComp",
     function(object) {
@@ -79,6 +81,7 @@ setMethod(
     }
 )
 
+
 # Constructor ========================================================
 
 #' Inference of ligand-receptor interactions based on regulation
@@ -102,13 +105,13 @@ setMethod(
 #' the other cell populations as above. The second comparison could be
 #' B-cells against all the other populations. Now, calling
 #' \code{BSRInferenceComp()}
-#' with comparison macrophages vs. the rest and, as source comparison, B-cells
-#' vs. the rest, will result in inferring interactions between B-cells
-#' (ligands) and macrophages (receptors and downstream pathways). To obtain
-#' macrophages to B-cells paracrine interactions, it is necessary to call the
-#' method a second time with permuted cluster comparison names. Another example
-#' in spatial transcriptomics could be two thin bands at the boundary of two
-#' tissue regions, one emitting the ligand and the other one expressing the
+#' with comparison macrophages *versus* the rest and, as source comparison,
+#' B-cells *versus* the rest, will result in inferring interactions between
+#' B-cells (ligands) and macrophages (receptors and downstream pathways). To
+#' obtain macrophages to B-cells paracrine interactions, it is necessary to call
+#' the method a second time with permuted cluster comparison names. Another
+#' example in spatial transcriptomics could be two thin bands at the boundary of
+#' two tissue regions, one emitting the ligand and the other one expressing the
 #' receptor.
 #'
 #' In this initial inference, all the receptor-containing pathways are reported,
@@ -429,6 +432,7 @@ setMethod("sourceComparisonName<-", "BSRInferenceComp", function(x, value) {
 setGeneric("tgPval", signature="x",
     function(x) standardGeneric("tgPval")
 )
+
 #' Target gene P-values accessor
 #'
 #' @name tgPval
@@ -568,8 +572,7 @@ setMethod(
 )
 
 
-# Rescoring & updating ===========
-
+# Rescoring & updating =========================================================
 
 #' Inference re-scoring
 #'
@@ -709,7 +712,7 @@ setGeneric("updateInference", signature="obj",
 #' initial BSRInferenceComp object. If a restriction on the targets
 #' was applied, then the update is likely to miss some targets, i.e.,
 #' the statistical analysis will be wrong.
-#' 
+#'
 #' In case no L-R interaction is above the required thresholds, the
 #' value `NULL` is returned.
 #'
@@ -717,7 +720,7 @@ setGeneric("updateInference", signature="obj",
 #' lengthy computations with scRNA-seq data and multiple cell
 #' populations.
 #'
-#' The main role of this method is to support our SingleCellSignalR v2
+#' The main role of this method is to support our SingleCellSignalR Version 2
 #' package.
 #'
 #' @export
@@ -834,7 +837,7 @@ setMethod("updateInference", "BSRInferenceComp", function(obj, bsrcc,
         if (logTransf) {
             sq <- sqrt(inter$L.expr * inter$R.expr)
         } else {
-            sq <- sqrt(log1p(inter$L.expr) / log(2) * 
+            sq <- sqrt(log1p(inter$L.expr) / log(2) *
 			           log1p(inter$R.expr) / log(2))
         }
         inter$LR.score <- sq / (mu + sq)
@@ -934,7 +937,7 @@ setMethod("updateInference", "BSRInferenceComp", function(obj, bsrcc,
     # rescore and return
     rescoreInference(obj, par, rank.p = rank.p, fdr.proc = fdr.proc)
     
-}) # updateInference
+}) # updateInferenceComp
 
 
 # Reduction and pathway stat methods ===========================================
